#!/usr/bin/env python

#-----------------------------------------------------------------------
# checkxmlusingdtd.py
# Author: Bob Dondero
#-----------------------------------------------------------------------

import sys
from lxml import etree

#-----------------------------------------------------------------------

def main():

    if len(sys.argv) != 2:
        print('Usage: ' + sys.argv[0] + ' file', file=sys.stderr)
        sys.exit(1)

    xml_file_name = sys.argv[1]

    try:
        with open(xml_file_name, 'r', encoding='utf-8') as xml_file:
            xml_doc = xml_file.read()

        parser = etree.XMLParser(dtd_validation=True)
        etree.fromstring(xml_doc, parser)
        print('The document is well-formed and valid.')

    except Exception as ex:
        print(ex, file=sys.stderr)
        sys.exit(1)

#-----------------------------------------------------------------------

if __name__ == '__main__':
    main()

#-----------------------------------------------------------------------

# Example executions:

# $ python checkxmlusingdtd.py booksusingdtd.xml
# The document is well-formed and valid.

# $ python checkxmlusingdtd.py booksusingdtdinvalid.xml
# Element book content does not follow the DTD, expecting
#   (author , title , price), got (author price title ),
#   line 25, column 11 (booksusingdtdinvalid.xml, line 25)
