#!/usr/bin/env python

#-----------------------------------------------------------------------
# checkxmlusingxsd.py
# Author: Bob Dondero
#-----------------------------------------------------------------------

import sys
from lxml import etree

#-----------------------------------------------------------------------

def main():

    if len(sys.argv) != 3:
        print('Usage: ' + sys.argv[0] + ' xmlfile schemafile',
            file=sys.stderr)
        sys.exit(1)

    xml_file_name = sys.argv[1]
    schema_file_name = sys.argv[2]

    try:
        with open(schema_file_name, 'r', encoding='utf-8') \
            as schema_file:
            schema_doc = schema_file.read()

        with open(xml_file_name, mode='r', encoding='utf-8') \
            as xml_file:
            xml_doc = xml_file.read()

        schema = etree.XMLSchema(etree.XML(schema_doc))
        parser = etree.XMLParser(schema=schema)
        etree.fromstring(xml_doc, parser)

        print('The document is well-formed and valid.')

    except Exception as ex:
        print(ex, file=sys.stderr)
        sys.exit(1)

#-----------------------------------------------------------------------

if __name__ == '__main__':
    main()

#-----------------------------------------------------------------------

# Example executions:

# $ python checkxmlusingxsd.py booksusingxsd.xml books.xsd
# The document is well-formed and valid.

# $ python checkxmlusingxsd.py booksusingxsdinvalid.xml books.xsd
# Element 'price': This element is not expected.
#    Expected is ( title ). (<string>, line 0)
