//----------------------------------------------------------------------
// writeauthorssax.js
// Author: Bob Dondero
//----------------------------------------------------------------------

'use strict';

const fs = require('fs');
const saxparser = require('sax-parser');

//----------------------------------------------------------------------

function parse(cb) {
   let authorName = '';
   let inAuthorElement = false;

   cb.onStartElementNS(function(elem, attrs, prefix, uri, namespace) {
      if (elem === 'author')
         inAuthorElement = true;
   });

   cb.onCharacters(function(chars) {
      if (inAuthorElement)
         authorName += chars;
   });

   cb.onEndElementNS(function(elem, prefix, uri) {
      if (elem === 'author') {
         process.stdout.write(authorName + '\n');
         authorName = '';
         inAuthorElement = false;
      }
   });
}

//----------------------------------------------------------------------

function parseFile(err, xmlDoc) {
   if (err) {
      process.stderr.write(err.message + '\n');
      process.exit(1);
   }

   let parser = new saxparser.SaxParser(parse);
   parser.parseString(xmlDoc);
}

//----------------------------------------------------------------------

function main() {
   fs.readFile('books.xml', 'utf-8', parseFile);
}

if (require.main === module)
   main(process.argv);
