#!/usr/bin/env python

#-----------------------------------------------------------------------
# writeauthorssax.py
# Author: Bob Dondero
#-----------------------------------------------------------------------

import sys
import xml.sax

#-----------------------------------------------------------------------

class AuthorsHandler(xml.sax.ContentHandler):

    def __init__(self):
        xml.sax.ContentHandler.__init__(self)
        self._in_author_element = False
        self._author_name = ''

    def startElement(self, name, attrs):
        if name == 'author':
            self._in_author_element = True

    def characters(self, content):
        if self._in_author_element:
            self._author_name += content

    def endElement(self, name):
        if name == 'author':
            print(self._author_name)
            self._author_name = ''
            self._in_author_element = False

#-----------------------------------------------------------------------

def main():

    try:
        with open('books.xml', 'r', encoding='utf-8') as xml_file:
            xml_doc = xml_file.read()

        xml.sax.parseString(xml_doc, AuthorsHandler())

    except Exception as ex:
        print(ex, file=sys.stderr)
        sys.exit(1)

#-----------------------------------------------------------------------

if __name__ == '__main__':
    main()
