//----------------------------------------------------------------------
// writebooks.js
// Author: Bob Dondero
//----------------------------------------------------------------------

'use strict';

const fs = require('fs');
const xmldom = require('xmldom');

//----------------------------------------------------------------------

function parseFile(err, xmlDoc) {
   if (err) {
      process.stderr.write(err.message + '\n');
      process.exit(1);
   }

   let parser = new xmldom.DOMParser();
   let xmlDomTree = parser.parseFromString(xmlDoc, 'text/xml');

   let booksNode = xmlDomTree.childNodes[10];

   let i = 1;
   while (i < booksNode.childNodes.length) {
      let bookNode = booksNode.childNodes[i];

      let isbnNode = bookNode.childNodes[1];
      let authorNode = bookNode.childNodes[3];
      let titleNode = bookNode.childNodes[5];
      let priceNode = bookNode.childNodes[7];

      let isbn = isbnNode.childNodes[0].nodeValue;
      let author = authorNode.childNodes[0].nodeValue;
      let title = titleNode.childNodes[0].nodeValue;
      let price = priceNode.childNodes[0].nodeValue;

      let currency =
         priceNode.attributes.getNamedItem('currency').nodeValue;

      process.stdout.write('ISBN: ' + isbn + '\n');
      process.stdout.write('Author: ' + author + '\n');
      process.stdout.write('Title: ' + title + '\n');
      process.stdout.write('Price: ' +  price + ' ' +
         currency + '\n');
      process.stdout.write('\n');
      i += 2;
   }
}

//----------------------------------------------------------------------

function main() {
   fs.readFile('books.xml', 'utf-8', parseFile);
}

if (require.main === module)
   main();
