//----------------------------------------------------------------------
// writebooksshort.js
// Author: Bob Dondero
//----------------------------------------------------------------------

'use strict';

const fs = require('fs');
const xmldom = require('xmldom');

//----------------------------------------------------------------------

function parseFile(err, xmlDoc) {
   if (err) {
      process.stderr.write(err.message + '\n');
      process.exit(1);
   }

   let parser = new xmldom.DOMParser();
   let xmlDomTree = parser.parseFromString(xmlDoc, 'text/xml');

   let bookNodes = xmlDomTree.getElementsByTagName('book');

   for (let i = 0; i < bookNodes.length; i++) {
      let bookNode = bookNodes[i];

      let isbnNode = bookNode.getElementsByTagName('isbn')[0];
      let authorNode = bookNode.getElementsByTagName('author')[0];
      let titleNode = bookNode.getElementsByTagName('title')[0];
      let priceNode = bookNode.getElementsByTagName('price')[0];

      let isbn = isbnNode.childNodes[0].nodeValue;
      let author = authorNode.childNodes[0].nodeValue;
      let title = titleNode.childNodes[0].nodeValue;
      let price = priceNode.childNodes[0].nodeValue;
      let currency =
         priceNode.attributes.getNamedItem('currency').nodeValue;

      process.stdout.write('ISBN: ' + isbn + '\n');
      process.stdout.write('Author: ' + author + '\n');
      process.stdout.write('Title: ' + title + '\n');
      process.stdout.write('Price: ' +  price + ' ' + currency + '\n');
      process.stdout.write('\n');
   }
}

//----------------------------------------------------------------------

function main() {
   fs.readFile('books.xml', 'utf-8', parseFile);
}

if (require.main === module)
   main();
