//----------------------------------------------------------------------
// writedom.js
// Author: Bob Dondero
//----------------------------------------------------------------------

'use strict';

const fs = require('fs');
const xmldom = require('xmldom');

//----------------------------------------------------------------------

function handleWhiteSpace(s) {
    if (s === null)
        return 'None';
    if (s.trim() === '')
        return 'WHITESPACE';
    return s;
}

//----------------------------------------------------------------------

function translateNodeType(nodeType) {
    if (nodeType ===  1) return 'Element';
    if (nodeType ===  2) return 'Attribute';
    if (nodeType ===  3) return 'Text';
    if (nodeType ===  4) return 'Cdata Section';
    if (nodeType ===  5) return 'Entity Reference';
    if (nodeType ===  6) return 'Entity';
    if (nodeType ===  7) return 'Processing Instruction';
    if (nodeType ===  8) return 'Comment';
    if (nodeType ===  9) return 'Document';
    if (nodeType === 10) return 'Document Type';
    if (nodeType === 11) return 'Document Fragment';
    if (nodeType === 12) return 'Notation';
    return 'Error';
}

//----------------------------------------------------------------------

function writeDomTree(node, indentLevel) {
   for (let i = 0; i < indentLevel; i++)
      process.stdout.write('   ');

   process.stdout.write(translateNodeType(node.nodeType));
   process.stdout.write(': ');
   process.stdout.write(String(node.nodeName));
   process.stdout.write('=');
   process.stdout.write(handleWhiteSpace(node.nodeValue));

   let attributes = node.attributes;
   if (attributes)
      for (let i = 0; i < attributes.length; i++) {
         let attribute = attributes.item(i);
         process.stdout.write(' (');
         process.stdout.write(translateNodeType(attribute.nodeType));
         process.stdout.write(': ');
         process.stdout.write(attribute.nodeName);
         process.stdout.write('=');
         process.stdout.write(handleWhiteSpace(attribute.nodeValue));
         process.stdout.write(')');
      }
   process.stdout.write('\n');
   if (node.childNodes)
      for (let i = 0; i < node.childNodes.length; i++) {
         let child = node.childNodes[i];
         writeDomTree(child, indentLevel + 1);
      }
}

//----------------------------------------------------------------------

function parseFile(err, xmlDoc) {
   if (err) {
      process.stderr.write(err.message + '\n');
      process.exit(1);
   }

   let parser = new xmldom.DOMParser();
   let xmlDomTree = parser.parseFromString(xmlDoc, 'text/xml');

   writeDomTree(xmlDomTree, 0);
}

//----------------------------------------------------------------------

function main() {
   if (process.argv.length !== 3) {
      process.stderr.write('Usage: ' + process.argv[0] + ' '
         + process.argv[1] + ' file\n');
      process.exit(1);
   }

   let xmlFileName = process.argv[2];

   fs.readFile(xmlFileName, 'utf-8', parseFile);
}

//----------------------------------------------------------------------

if (require.main === module)
   main();
