#!/usr/bin/env python

#-----------------------------------------------------------------------
# writedom.py
# Author: Bob Dondero
#-----------------------------------------------------------------------

import sys
import xml.dom.minidom

#-----------------------------------------------------------------------

def handle_white_space(string):

    if string is None:
        return 'None'
    if string.strip() == '':
        return 'WHITESPACE'
    return string

#-----------------------------------------------------------------------

def translate_node_type(node_type):

    node_type_map = {
        xml.dom.minidom.Node.ELEMENT_NODE:
            'Element',
        xml.dom.minidom.Node.ATTRIBUTE_NODE:
            'Attribute',
        xml.dom.minidom.Node.TEXT_NODE:
            'Text',
        xml.dom.minidom.Node.CDATA_SECTION_NODE:
            'Cdata Section',
        xml.dom.minidom.Node.ENTITY_REFERENCE_NODE:
            'Entity Reference',
        xml.dom.minidom.Node.ENTITY_NODE:
            'Entity',
        xml.dom.minidom.Node.PROCESSING_INSTRUCTION_NODE:
            'Processing Instruction',
        xml.dom.minidom.Node.COMMENT_NODE:
            'Comment',
        xml.dom.minidom.Node.DOCUMENT_NODE:
            'Document',
        xml.dom.minidom.Node.DOCUMENT_TYPE_NODE:
            'Document Type',
        xml.dom.minidom.Node.DOCUMENT_FRAGMENT_NODE:
            'Document Fragment',
        xml.dom.minidom.Node.NOTATION_NODE:
            'Notation'
    }

    return node_type_map.get(node_type, 'Error')

#-----------------------------------------------------------------------

def write_dom_tree(node, indent_level):

    for _ in range(indent_level):
        print('   ', end='')

    print(translate_node_type(node.nodeType), end='')
    print(': ', end='')
    print(node.nodeName, end='')
    print('=', end='')
    print(handle_white_space(node.nodeValue), end='')

    attributes = node.attributes
    if attributes is not None:
        keys = list(attributes.keys())
        for key in keys:
            attribute = attributes.getNamedItem(key)
            print(' (', end='')
            print(translate_node_type(attribute.nodeType), end='')
            print(': ', end='')
            print(key, end='')
            print('=', end='')
            print(handle_white_space(attribute.nodeValue), end='')
            print(')', end='')

    print()

    for child in node.childNodes:
        write_dom_tree(child, indent_level + 1)

#-----------------------------------------------------------------------

def main():

    if len(sys.argv) != 2:
        print('Usage: ' + sys.argv[0] + ' file', file=sys.stderr)
        sys.exit(1)

    xml_file_name = sys.argv[1]

    try:
        with open(xml_file_name, 'r', encoding='utf-8') as xml_file:
            xml_doc = xml_file.read()

        xml_dom_tree = xml.dom.minidom.parseString(xml_doc)

        write_dom_tree(xml_dom_tree, 0)

    except Exception as ex:
        print(ex, file=sys.stderr)
        sys.exit(1)

#-----------------------------------------------------------------------

if __name__ == '__main__':
    main()
